@@ -6,16 +6,14 @@
   SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-#ifndef KSMTP_FAKESERVER_H
-#define KSMTP_FAKESERVER_H
+#pragma once
 
 #include <QMutex>
-#include <QTcpServer>
 #include <QTcpSocket>
 #include <QThread>
 
 Q_DECLARE_METATYPE(QList<QByteArray>)
-
+class QTcpServer;
 class FakeServer : public QThread
 {
     Q_OBJECT
@@ -52,4 +50,3 @@ private:
     QList<QTcpSocket *> m_clientSockets;
 };
 
-#endif // KSMTP_FAKESERVER_H
