@@ -13,31 +13,31 @@
 using namespace Akonadi;
 using namespace MailTransport;
 
-class SentActionAttribute::Action::Private : public QSharedData
+class MailTransport::SentActionAttributeActionPrivate : public QSharedData
 {
 public:
-    Private()
+    SentActionAttributeActionPrivate()
     {
     }
 
-    Private(const Private &other)
+    SentActionAttributeActionPrivate(const SentActionAttributeActionPrivate &other)
         : QSharedData(other)
+        , mType(other.mType)
+        , mValue(other.mValue)
     {
-        mType = other.mType;
-        mValue = other.mValue;
     }
 
-    Type mType = Invalid;
+    SentActionAttribute::Action::Type mType = SentActionAttribute::Action::Invalid;
     QVariant mValue;
 };
 
 SentActionAttribute::Action::Action()
-    : d(new Private)
+    : d(new SentActionAttributeActionPrivate)
 {
 }
 
 SentActionAttribute::Action::Action(Type type, const QVariant &value)
-    : d(new Private)
+    : d(new SentActionAttributeActionPrivate)
 {
     d->mType = type;
     d->mValue = value;
@@ -76,21 +76,18 @@ bool SentActionAttribute::Action::operator==(const Action &other) const
     return (d->mType == other.d->mType) && (d->mValue == other.d->mValue);
 }
 
-class Q_DECL_HIDDEN SentActionAttribute::Private
+class MailTransport::SentActionAttributePrivate
 {
 public:
-    Action::List mActions;
+    SentActionAttribute::Action::List mActions;
 };
 
 SentActionAttribute::SentActionAttribute()
-    : d(new Private)
+    : d(new SentActionAttributePrivate)
 {
 }
 
-SentActionAttribute::~SentActionAttribute()
-{
-    delete d;
-}
+SentActionAttribute::~SentActionAttribute() = default;
 
 void SentActionAttribute::addAction(Action::Type type, const QVariant &value)
 {
