@@ -9,13 +9,18 @@
 
 #include <mailtransportakonadi_export.h>
 
+#include <Akonadi/Attribute>
 #include <QSharedDataPointer>
 #include <QVariant>
 #include <QVector>
-#include <attribute.h>
+
+#include <memory>
 
 namespace MailTransport
 {
+class SentActionAttributePrivate;
+class SentActionAttributeActionPrivate;
+
 /**
  * @short An Attribute that stores the action to execute after sending.
  *
@@ -93,8 +98,7 @@ public:
 
     private:
         //@cond PRIVATE
-        class Private;
-        QSharedDataPointer<Private> d;
+        QSharedDataPointer<SentActionAttributeActionPrivate> d;
         //@endcond
     };
 
@@ -129,8 +133,7 @@ public:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<SentActionAttributePrivate> const d;
     //@endcond
 };
 }
